/**
 *  Script Name  : TestOrderRandomBulk.groovy
 *
 *  Purpose      : To print a bulk entries with random values for each Order instance 
 *
 *  Environment  : Tested with -> Groovy Version: 2.4.3 JVM: 1.7.0_80 Vendor: Oracle Corporation OS: Windows 7
 *
 *  URL to refer : https://examples.javacodegeeks.com/jvm-languages/groovy
 *
 *  Author       : Raghavan alias Saravanan Muthu (Java Code Geeks)
 *  Date         : 11 Apr 2016, Monday
 */

package com.javacodegeeks.example.groovy.scripting

// a list of values for customer names
def namesList = ['Raghavan', 'Ganesh', 'Karthick', 'Sathish', 'Kanna', 'Raja', 
         'Karthiga', 'Manoj', 'Saravanan',  'Adi', 'Dharma', 'Jhanani', 
         'Ulags', 'Prashant', 'Anand']

// a Map to hold a set of countries and the currency for each
def countryCurrencyMap = ['India':'INR', 'Australia' : 'AUD', 'Bahrain' : 'BHD', 
              'Dubai' : 'AED', 'Saudi' : 'SAR', 'Belgium' : 'EUR', 
              'Canada' : 'CAD', 'Hong Kong' : 'HKD', 'USA' : 'USD', 
              'UK' : 'GBP', 'Singapore' : 'SGD']

// a list to hold random amount values
def amountList = ['1234.00', '1542.99', '111.2', '18920.11', '4567.00', '9877.12', 
      '2500.00', '50000.00', '6500.18', '7894.11', '1234.56', '1756.55', '8998.11']

// a list to hold different payment modes
def paymentModeList = ['Cash', 'Card', 'Cheque']

int noOfRecords = 5

println " "

// Take a default value of 5 for the total number of entries to be printed
// if nothing was specified in the command prompt while invoking the script
if(args.length>0) {
   noOfRecords = Integer.parseInt(args[0])
} else {
   println "Considering the default value for total # of entries"
}

println "No of entries to be printed : " + noOfRecords

def random = new Random()
def randomIntName, randomIntCountry, randomIntAmount, randomIntMode
def orderRandom, mapKey

def outputToWrite = ""

for(int i = 0; i < noOfRecords; i++)
{
    randomIntName = random.nextInt(namesList.size())
    randomIntCountry = random.nextInt(countryCurrencyMap.size())
    randomIntAmount = random.nextInt(amountList.size())
    randomIntMode = random.nextInt(paymentModeList.size())
    
    mapKey = countryCurrencyMap.keySet()[randomIntCountry]

    // create an Order instance by calling a constructor with all the random values 
    orderRandom = new Order(customerName : namesList[randomIntName], country: mapKey, 
        currency: countryCurrencyMap[mapKey], price: amountList[randomIntAmount], 
        paymentMode: paymentModeList[randomIntMode])
    
    outputToWrite += orderRandom.toString()
    
    // we need a new line for each order entry in the text file
    outputToWrite += System.getProperty("line.separator")
}

// Directory to which the output file to be written
def baseDir="outputFiles"                             
// name of the output file
def fileName='outputTest.txt'                                        

//Groovy's way of easy syntax to write to a file                                                                
new File(baseDir, fileName).withWriter('utf-8') { writer ->     
    writer.writeLine outputToWrite 
}                                                               
              
println ""                                                  
println "Contents are written to the file -> [$fileName] in the directory [$baseDir]" 
println ""

// 'line' is an implicit variable provided by Groovy  
new File(baseDir, fileName).eachLine {         
        line -> println line                          
}                                                  

println "----------------- "
println " == COMPLETED ==  "
println "----------------- "