/**
 *  Script Name  : TestOrderRandomInterval.groovy
 *
 *  Purpose      : To print a bulk entries with random values for each Order instance.
 *            This script will write in loop for a fixed number of iterations while 
 *            sleeping for a fixed time between each iteration
 *
 *  Environment  : Tested with -> Groovy Version: 2.4.3 JVM: 1.7.0_80 Vendor: Oracle Corporation OS: Windows 7
 *
 *  URL to refer : https://examples.javacodegeeks.com/jvm-languages/groovy
 *
 *  Author       : Raghavan alias Saravanan Muthu (Java Code Geeks)
 *  Date         : 11 Apr 2016, Monday
 */

package com.javacodegeeks.example.groovy.scripting

// a list of values for customer names
def namesList = ['Raghavan', 'Ganesh', 'Karthick', 'Sathish', 'Kanna', 'Raja',
                 'Karthiga', 'Manoj', 'Saravanan',  'Adi', 'Dharma', 'Jhanani',
                 'Ulags', 'Prashant', 'Anand']

// a Map to hold a set of countries and the currency for each
def countryCurrencyMap = ['India':'INR', 'Australia' : 'AUD', 'Bahrain' : 'BHD',
                          'Dubai' : 'AED', 'Saudi' : 'SAR', 'Belgium' : 'EUR',
                          'Canada' : 'CAD', 'Hong Kong' : 'HKD', 'USA' : 'USD',
                          'UK' : 'GBP', 'Singapore' : 'SGD']

// a list to hold random amount values
def amountList = ['1234.00', '1542.99', '111.2', '18920.11', '4567.00', '9877.12',
          '2500.00', '50000.00', '6500.18', '7894.11', '1234.56', '1756.55', '8998.11']

// a list to hold different payment modes
def paymentModeList = ['Cash', 'Card', 'Cheque']

def getNow() {
    new Date().format("yyyyMMdd_HHmmss")
}

// default value if nothing is specified during runtime at the command prompt
int noOfRecords = 5

println ""

// Take a default value of 5 for the total number of entries to be printed
// if nothing was specified in the command prompt while invoking the script
if(args.length>0) {                                                    
   noOfRecords = Integer.parseInt(args[0])                             
} else {                                                               
   println "Considering the default value for total # of entries : 5" 
}                                                                      

println "Total # of records to be printed : $noOfRecords"

def random = new Random()
def randomIntName, randomIntCountry, randomIntAmount, randomIntMode
def orderRandom, mapKey

// a variable to hold the output content to be written into a file
def outputToWrite = ""

//no of iterations this script will execute
def MAX_ITERATIONS = 2; 

// interval to let this script sleep (1000ms=1s, here it will be for 1 min)
def SLEEP_INTERVAL = 1000*60*1; 

// Directory to which the output files to be written
def baseDir = "."
// Prefix of the output file
def fileNamePrefix = 'outputTest.txt'
// Name of the output file which will vary in the loop below
def fileName = fileNamePrefix

println " "
println "[*] This script will write $noOfRecords records for $MAX_ITERATIONS iterations"
println " "

for(int iteration = 1; iteration <= MAX_ITERATIONS; iteration++) 
{
    /* Empty the buffer to avoid the previous stuff to be appended over and over */
    outputToWrite = ""

    for(int i = 0; i < noOfRecords; i++)
    {
        randomInt = random.nextInt(namesList.size())
        randomIntCountry = random.nextInt(countryCurrencyMap.size())
        randomIntAmount = random.nextInt(amountList.size())
        randomIntMode = random.nextInt(paymentModeList.size())
    
        mapKey = countryCurrencyMap.keySet()[randomIntCountry]

        // Instantiate a new Order with the random values
        orderRandom = new Order(customerName : namesList[randomInt], 
                country: mapKey, currency: countryCurrencyMap[mapKey], 
                price: amountList[randomIntAmount], 
                paymentMode: paymentModeList[randomIntMode])
    
        // keep appending it to the output variable
        outputToWrite += orderRandom.toString()

        // append a new line so that the next entry will fall on the next line
        outputToWrite += System.getProperty("line.separator")
    }
    
    /* Filename can better be unique */
    fileName = fileNamePrefix + "_" + iteration + "_" + getNow()

    new File(baseDir, fileName).withWriter('utf-8') { writer ->     
        writer.writeLine outputToWrite 
    }                                                               
                                                                
    println getNow() + " : Contents are written to the file -> [$fileName] in the directory [$baseDir]" 
    println ""

    // 'line' is an implicit variable provided by Groovy  
    new File(baseDir, fileName).eachLine {         
            line -> println line                          
    }

    println getNow() + " ...... Script will sleep for ${SLEEP_INTERVAL} milliseconds [1000ms=1s]......"
    println " "
    sleep(SLEEP_INTERVAL)
    println getNow() + " .............. Script awaken ......................"
    println ""
}

println " "
println "----------------- "
println " == COMPLETED ==  "
println "----------------- "