/**                                                                                                             
 *  Script Name  : dbCreateTable.groovy                                                                                 
 *                                                                                                              
 *  Purpose      : To demonstrate the usage of Scripting in Groovy. This is a SQL Script to create    
 *                      table named 'GroovyScriptTest' in MySQL database named 'test'           
 *                                                                                                              
 *  Environment  : Tested with -> Groovy Version: 2.4.3 JVM: 1.7.0_80 Vendor: Oracle Corporation OS: Windows 7  
 *                                                                                                              
 *  URL to refer : https://examples.javacodegeeks.com/jvm-languages/groovy                                     
 *                                                                                                              
 *  Author       : Raghavan alias Saravanan Muthu (Java Code Geeks)                                             
 *  Date         : 11 Apr 2016, Monday                                                                          
 */                                                                                                             
                                                                                                                
package com.javacodegeeks.example.groovy.scripting;                                                             

// These two lines are for facilitating the System Classloader to pickup the 
// MySQL JDBC Connector Jar file from its classpath.  
//   1. Required when you invoke the script in GroovyConsole
//   2. Not required if you invoke the script in Command Prompt with a -cp option 
//        specifying the classpath to locate the jar file
@GrabConfig(systemClassLoader=true)
@Grab('mysql:mysql-connector-java:5.1.29')

// Database related methods are present in Sql class
// we need to import the Sql class from groovy.sql package
import groovy.sql.Sql

// we read the database properties from DBProps class 
// which had already read those values from the configuration file
def url = DBProps.dbUrl
def user = DBProps.dbUser
def password = DBProps.dbPwd
def driver = DBProps.dbDriver
def tableName = DBProps.dbTblName
 
// Groovy's way of executing SQL statement after obtaining a connection
// from database. withInstance is a special construct that helps the
// connection closed automatically even in case of any errors
Sql.withInstance(url, user, password, driver) { sql ->
 
  sql.execute '''
      CREATE TABLE ''' + tableName + '''
    (
        Id INTEGER NOT NULL AUTO_INCREMENT PRIMARY KEY,
        NAME VARCHAR(30),
        COUNTRY VARCHAR(20),
        PRICE FLOAT(8,2),
        CURRENCY VARCHAR(3),
        PAYMENT_MODE VARCHAR(10),
        ORDER_DATE DATETIME DEFAULT CURRENT_TIMESTAMP
    );
  '''

  println "Table [${tableName}] created successfully"
}