/**
 *  Script Name  : dbInsertValueSingleFile.groovy
 *
 *  Purpose      : To demonstrate the usage of Scripting in Groovy. This is a script to insert
 *                    the values from one flat file named 'outputTest.txt' from the 'outputFiles' 
 *                    subdirectory into the 'GroovyScriptTest' database table
 *
 *  Environment  : Tested with -> Groovy Version: 2.4.3 JVM: 1.7.0_80 Vendor: Oracle Corporation OS: Windows 7
 *
 *  URL to refer : https://examples.javacodegeeks.com/jvm-languages/groovy
 *
 *  Author       : Raghavan alias Saravanan Muthu (Java Code Geeks)
 *  Date         : 11 Apr 2016, Monday
 */

package com.javacodegeeks.example.groovy.scripting

// These two lines are for facilitating the System Classloader to pickup the 
// MySQL JDBC Connector Jar file from its classpath.  
//   1. Required when you invoke the script in GroovyConsole
//   2. Not required if you invoke the script in Command Prompt with a -cp option 
//        specifying the classpath to locate the jar file
@GrabConfig(systemClassLoader=true)
@Grab('mysql:mysql-connector-java:5.1.29')

import groovy.sql.Sql

// Properties of DBProps class parsed out of the configuration file
def url = DBProps.dbUrl
def user = DBProps.dbUser
def password = DBProps.dbPwd
def driver = DBProps.dbDriver
def tableName = DBProps.dbTblName

def baseDir="./outputFiles"
def fileName = 'outputTest.txt'

// a list to hold the list of valid (non-empty) lines in the flat file
def list = new File(baseDir, fileName).readLines()*.trim()

def orderList = []

list.each { it ->
       // Consider ONLY the non-empty lines in the flat file
       if(it.trim().length() > 0)
          orderList.add(new Order().initOrder(it))
}

Sql.withInstance(url, user, password, driver) { sql ->
  //process each line which is an Order Instance
  orderList.each { it -> 
      sql.execute """
          INSERT INTO ${Sql.expand(tableName)}
            (NAME, COUNTRY, PRICE, CURRENCY, PAYMENT_MODE)
            VALUES
            (
                ${it.customerName}, ${it.country},
                ${it.price}, ${it.currency}, ${it.paymentMode}
            );
      """
  }

  println "Total Rows Inserted to db : " + orderList.size()
}


println " "
println "----------------- "
println " == COMPLETED ==  "
println "----------------- "