/**                                                                                                             
 *  Script Name  : dbProperties.groovy                                                                                 
 *                                                                                                              
 *  Purpose      : To demonstrate the usage of Scripting in Groovy. This is a script to
 *                      retrieve the database properties configured in a properties file
 *                      named 'db.properties' in the same directory         
 *                                                                                                              
 *  Environment  : Tested with -> Groovy Version: 2.4.3 JVM: 1.7.0_80 Vendor: Oracle Corporation OS: Windows 7  
 *                                                                                                              
 *  URL to refer : https://examples.javacodegeeks.com/jvm-languages/groovy                                     
 *                                                                                                              
 *  Author       : Raghavan alias Saravanan Muthu (Java Code Geeks)                                             
 *  Date         : 11 Apr 2016, Monday                                                                          
 */                                                                                                             

package com.javacodegeeks.example.groovy.scripting

class DBProps
{
    // meaningful class level variables for each of the db properties
    static String dbType, dbHost, dbPort, dbName, dbUser, dbPwd, dbUrl, dbDriver, dbTblName
    
    // class level varaibles for the properties file 
    static String baseDir=".", propsFileName = 'db.properties'
    
    // class level variables to hold the properties loaded
    static def props = new Properties(), config

    //static initializer block (gets invoked when the class is loaded and only once)
    static
    {
        // Groovy's simple way to load a configuration file from a directory and
        // create a Properties (java.util.Properties) instance out of it    
        new File(baseDir, propsFileName).withInputStream {
          stream -> props.load(stream)
        }

        // ConfigSlurper gives a way to access properties using GPath expressions (dot notation)
        config = new ConfigSlurper().parse(props)
        
        // Assign the value of each property through ConfigSlurper instance
        dbType    = config.db.type
        dbName    = config.db.name
        dbHost    = config.db.host
        dbPort    = config.db.port
        dbUser    = config.db.user
        dbPwd     = config.db.pwd
        dbDriver  = config.db.driver
        dbTblName = config.db.tableName

        dbUrl = 'jdbc:' + dbType + '://' + dbHost + ':' + dbPort + '/' + dbName
        //assert dbUrl=='jdbc:mysql://localhost:3306/test'
    }

    static printValues()
    {
        println "Db Type     : " + DBProps.dbType
        println "Db Name     : " + DBProps.dbName        
        println "Db Host     : " + DBProps.dbHost
        println "Db Port     : " + DBProps.dbPort        
        println "Db User     : " + DBProps.dbUser
        println "Db Pwd      : " + DBProps.dbPwd
        println "Db URL      : " + DBProps.dbUrl
        println "JDBC Driver : " + DBProps.dbDriver
        println "Table Name  : " + DBProps.dbTblName       
    }
}

// To test the values through the same script
DBProps.printValues()