/**                                                                                                            
 *  Script Name  : dbSelectRows.groovy                                                                                
 *                                                                                                             
 *  Purpose      : To demonstrate the usage of Scripting in Groovy. This is a SQL Script to             
 *                      select all the rows from the 'GroovyScriptTest' table in 
 *                      MySQL database named 'test'                          
 *                                                                                                             
 *  Environment  : Tested with -> Groovy Version: 2.4.3 JVM: 1.7.0_80 Vendor: Oracle Corporation OS: Windows 7 
 *                                                                                                             
 *  URL to refer : https://examples.javacodegeeks.com/jvm-languages/groovy                                     
 *                                                                                                             
 *  Author       : Raghavan alias Saravanan Muthu (Java Code Geeks)                                            
 *  Date         : 11 Apr 2016, Monday                                                                         
 */                                                                                                            
                                                                                                               
package com.javacodegeeks.example.groovy.scripting;                                                            

// These two lines are for facilitating the System Classloader to pickup the 
// MySQL JDBC Connector Jar file from its classpath.  
//   1. Required when you invoke the script in GroovyConsole
//   2. Not required if you invoke the script in Command Prompt with a -cp option 
//        specifying the classpath to locate the jar file
@GrabConfig(systemClassLoader=true)
@Grab('mysql:mysql-connector-java:5.1.29')
                                                                                                               
import groovy.sql.Sql

def url = DBProps.dbUrl
def user = DBProps.dbUser
def password = DBProps.dbPwd
def driver = DBProps.dbDriver
def tableName = DBProps.dbTblName

def sql = Sql.newInstance(url, user, password, driver)
                                                      
def query= '''select count(*) as total_rows from ''' +  tableName
                                                                             
def totalRows                                                         
                                                                                               
sql.query(query) { resultSet ->                                                                
    while(resultSet.next()) {                                                                  
        totalRows = resultSet.getString(1)                                                      
        println "Total Rows in the table [${tableName}] :: ${totalRows}"                                                                            
    }                                                                                          
}                                                                                              
                                                                                               
def fieldsList = "Id, Name, Country, Price, Currency, Payment_Mode, Order_Date"

query='''                                                                                    
    Select
       Id, Name, Country, Price, Currency, Payment_Mode, Order_Date
    from                                                                                       
        ''' + tableName                       

// declare the individual variables to hold the respective values from database
def id, name, country, orderNo, price, currency, mode, orderDate

// a list to hold a set of Order Instances
def orderList = []

// a variable to hold an Order Instance prepared out of the values extracted from database
def order

sql.query(query) { rs ->
    while(rs.next()) 
    {
        // extract each field from the resultset(rs) and 
        // store them in separate variables
        id = rs.getString(1)
        name = rs.getString(2)
        country = rs.getString(3)
        price = rs.getString(4)
        currency = rs.getString(5)
        mode = rs.getString(6)
        orderDate = rs.getString(7)
    
        // create an Order Instance from the values extracted
        order = new Order('id' : id, 'customerName': name, 'country': country, 'price': price, 
                    'currency' : currency, 'paymentMode' : mode, 'orderDate' : orderDate)
    
        // add the order instances into a collection (List)
        orderList.add(order)
    }
}

// Prepare the column headers with a fixed width for each
def fieldListDisplay = String.format("%-5s", "Id") + " | " + String.format("%-15s", "Customer Name") + " | "  + 
            String.format("%-10s", "Country") + " | " + String.format("%-8s", "Price") + " | " + 
            String.format("%-8s", "Currency") + " | " + String.format("%-12s", "Payment Mode") + " | " + 
            String.format("%-21s", "Order Date") + " | "

// an utility method to display a dash ("-") for a visual aid
// to keep the data aligned during the display in the console
def printDashes(limit) {
    for(int i = 0 ; i < limit; i++) 
        System.out.print("-")

    println ""    
}    

// Print only if there were any valid rows available in the database table
if(orderList.size()>0)
{
    //print the Headers
    println ""
    def dashWidth = 102
    printDashes(dashWidth)
    println fieldListDisplay
    printDashes(dashWidth)

    // Print each of the order instances
    // Here the toString() method will be invoked on the Order instance
    orderList.each { it ->
         println it
    }

    // To print a line with dashes to indicate the end of the display
    printDashes(dashWidth)
}

// Dont' forget to close the database connection
sql.close()